@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-spell-fu
 ;; Keywords: convenience
-;; Package-Version: 20250913.2251
-;; Package-Revision: b141e2e24e3d
+;; Package-Version: 20251031.8
+;; Package-Revision: 6c7cdc971d23
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -137,7 +137,8 @@ use `spell-fu-dictionary-add'.")
 (defface spell-fu-incorrect-face
   '((((supports :underline (:style wave))) :underline (:style wave :color "red"))
     (t :underline t :inherit error))
-  "Face for incorrect spelling.")
+  "Face for incorrect spelling."
+  :group 'spell-fu)
 
 ;; See '-' as a word boundary \b, so 'full-screen' is detected as two words.
 (defvar-local spell-fu-syntax-table
